@@ -5,7 +5,9 @@ pyMelt
 
 A python package for performing mantle melting calculations.
 
-Developed and maintained by Simon Matthews (simonm@hi.is) and Kev Wong.
+
+Developed and maintained by Simon Matthews (simonm@hi.is), Kevin Wong, and Matthew Gleeson.
+
 
 This module facilitates calculations for melting of heterogeneous mantle, based on empirical
 parameterisations of the melting functions. The calculations assume complete thermal equilibrium
@@ -13,15 +15,13 @@ and complete chemical disequilibrium between adjacent mantle lithologies. Variou
 provided for performing decompression melting calculations.
 """
 
-__version__ = "0.5.1"
-__author__ = "Simon Matthews and Kevin Wong"
-__all__ = ['Mantle', 'hydrous_lithology']
-
-import pyMelt.lithologies
-# import pyMelt.meltingcolumn_classes
-import pyMelt.mantle_class
-from pyMelt.lithology_classes import hydrous_lithology
+__version__ = "2.00"
+__author__ = "Simon Matthews, Kevin Wong, Matthew Glesson"
 
 
-class Mantle(pyMelt.mantle_class.mantle):
-    __doc__ = pyMelt.mantle_class.mantle.__doc__
+from pyMelt import lithologies
+from pyMelt import geosettings
+from pyMelt.mantle_class import mantle
+from pyMelt.lithology_classes import hydrousLithology
+
+__all__ = ['hydrousLithology', 'mantle', 'lithologies', 'geosettings']
