@@ -12,14 +12,14 @@ at a spreading centre.
 import numpy as _np
 import pandas as _pd
 import matplotlib.pyplot as _plt
-from copy import copy
-from scipy.interpolate import interp1d
-from scipy.integrate import trapz
-from warnings import warn
+from copy import copy as _copy
+from scipy.interpolate import interp1d as _interp1d
+from scipy.integrate import trapz as _trapz
+from warnings import warn as _warn
+
+import pyMelt.chemistry as _chemistry
 
-import pyMelt.chemistry
 
-# Weighting function
 def weighting_expdecay(P, weighting_wavelength, weighting_amplitude=1.0):
     """
     Weights melts according to an exponential decay function, with the greatest weighting at the
@@ -42,6 +42,7 @@ def weighting_expdecay(P, weighting_wavelength, weighting_amplitude=1.0):
 
     return w
 
+
 class geoSetting(object):
     """
     Base clase for geological settings.
@@ -68,7 +69,7 @@ class geoSetting(object):
         The mantle object from which the melting column was calculated.
     """
 
-    def __init(self, MeltingColumn, weightingFunction = None, **kwargs):
+    def __init(self, MeltingColumn, weightingFunction=None, **kwargs):
         self.MeltingColumn = MeltingColumn
         self.lithologies = MeltingColumn.lithologies
         self.mantle = MeltingColumn.mantle
@@ -76,7 +77,7 @@ class geoSetting(object):
         self.kwargs = kwargs
 
     def crystallisationChemistry(self, mineralProportions, fractionate=True,
-                                  D = pyMelt.chemistry.defaultD):
+                                 D=_chemistry.defaultD):
         """
         Calculates the concentrations of elements in the homogenised magma following an interval
         of crystallisation.
@@ -100,7 +101,7 @@ class geoSetting(object):
         """
 
         X = 1 - sum(mineralProportions.values())
-        Dbulk = _pd.Series(index = self.chemistry.index, data = [0]*len(self.chemistry))
+        Dbulk = _pd.Series(index=self.chemistry.index, data=[0] * len(self.chemistry))
         for mineral in mineralProportions:
             Dbulk += mineralProportions[mineral] * D[mineral] / (1 - X)
         if fractionate is True:
@@ -109,8 +110,8 @@ class geoSetting(object):
             evolved_chemistry = self.chemistry / (X * (1 - Dbulk) + Dbulk)
         return evolved_chemistry
 
-    def plotSpider(self, normalisation = 'PM', plot_instantaneous=False, plot_original=True,
-                    crystal_fraction=None, element_order=None, **kwargs):
+    def plotSpider(self, normalisation='PM', plot_instantaneous=False, plot_original=True,
+                   crystal_fraction=None, element_order=None, **kwargs):
         """
         Plot a basic spider diagram of the chemical composition, optionally alongside the
         instantaneous melts and/or an evolved melt.
@@ -144,9 +145,9 @@ class geoSetting(object):
         """
         f, a = _plt.subplots(dpi=150)
 
-        default_norms = {'PM': pyMelt.chemistry.palme13_pm,
-                         'CI': pyMelt.chemistry.palme13_ci,
-                         'DM': pyMelt.chemistry.workman05_dmm}
+        default_norms = {'PM': _chemistry.palme13_pm,
+                         'CI': _chemistry.palme13_ci,
+                         'DM': _chemistry.workman05_dmm}
 
         if isinstance(normalisation, str):
             normalisation = default_norms[normalisation]
@@ -167,21 +168,21 @@ class geoSetting(object):
                         hi = lithmax
                     if lithmin < lo:
                         lo = lithmin
-                    normed_hi.append(hi/normalisation[el])
-                    normed_lo.append(lo/normalisation[el])
+                    normed_hi.append(hi / normalisation[el])
+                    normed_lo.append(lo / normalisation[el])
             a.fill_between(range(len(element_order)), normed_lo, normed_hi, alpha=0.2)
 
         if plot_original is True:
             normed = []
             for el in element_order:
-                normed.append(self.chemistry[el]/normalisation[el])
+                normed.append(self.chemistry[el] / normalisation[el])
             a.plot(range(len(element_order)), normed)
 
         if crystal_fraction is not None:
             unnormed = self.crystallisationChemistry(crystal_fraction, **kwargs)
             normed = []
             for el in element_order:
-                normed.append(unnormed[el]/normalisation[el])
+                normed.append(unnormed[el] / normalisation[el])
             a.plot(range(len(element_order)), normed)
 
         a.set_yscale('log')
@@ -191,7 +192,7 @@ class geoSetting(object):
 
         return f, a
 
-    def _weighting_coefficients(self, P, empty_value = 0.0):
+    def _weighting_coefficients(self, P, empty_value=0.0):
         """
         Calculates the weighting coefficients, or returns 0 if no weighting function is supplied.
 
@@ -261,11 +262,11 @@ class spreadingCentre(geoSetting):
     def __init__(self, MeltingColumn, P_lithosphere=0.0, extract_melt=False, steps=10001,
                  weightingFunction=None, **kwargs):
         self.MeltingColumn = MeltingColumn
-        self.lithologies = copy(MeltingColumn.lithologies)
+        self.lithologies = _copy(MeltingColumn.lithologies)
         self.mantle = MeltingColumn.mantle
-        self.P = copy(self.MeltingColumn.P)
-        self.T = copy(self.MeltingColumn.T)
-        self.F = copy(self.MeltingColumn.F)
+        self.P = _copy(self.MeltingColumn.P)
+        self.T = _copy(self.MeltingColumn.T)
+        self.F = _copy(self.MeltingColumn.F)
         self.P_lithosphere = P_lithosphere
         self.weightingFunction = weightingFunction
         self.kwargs = kwargs
@@ -291,10 +292,10 @@ class spreadingCentre(geoSetting):
             self.P = self.P[self.P > self.P_base_of_crust]
         else:
             self.F = self.F[self.P > self.P_lithosphere]
-            self.T = self.F[self.P > self.P_lithosphere]
+            self.T = self.T[self.P > self.P_lithosphere]
             for lith in self.lithologies:
                 self.lithologies[lith] = self.lithologies[lith][self.P > self.P_lithosphere]
-            self.P = self.F[self.P > self.P_lithosphere]
+            self.P = self.P[self.P > self.P_lithosphere]
 
     def _integrate_tri(self, P_base_existingLith=0.0, extract_melt=False, steps=1001):
         """
@@ -339,10 +340,10 @@ class spreadingCentre(geoSetting):
             P = self.P
             tc_lith = tc_lith.to_numpy()
         else:
-            interp_f = interp1d(self.P, tc)
+            interp_f = _interp1d(self.P, tc)
             interp_lith = []
             for i in range(self.mantle.number_lithologies):
-                interp_lith.append(interp1d(self.P, tc_lith[self.mantle.names[i]]))
+                interp_lith.append(_interp1d(self.P, tc_lith[self.mantle.names[i]]))
             P = _np.linspace(_np.nanmax(self.P), _np.nanmin(self.P), steps)
             tc = _np.zeros(_np.shape(P)[0])
             for i in range(len(P)):
@@ -363,12 +364,13 @@ class spreadingCentre(geoSetting):
 
         for i in range(_np.shape(P)[0]):
             if i != 0:
-                tc_int[i] = tc_int[i - 1] + tc[i] * (_np.abs(P[i] - P[i - 1]) + weights[i])
+                tc_int[i] = (tc_int[i - 1]
+                             + 0.5 * (tc[i] + tc[i - 1]) * (_np.abs(P[i] - P[i - 1]) + weights[i]))
                 tc_lith_int[i] = (tc_lith_int[i - 1]
-                                  + tc_lith[i] * (_np.abs(P[i] - P[i - 1]) + weights[i]))
+                                  + 0.5 * tc_lith[i] * (_np.abs(P[i] - P[i - 1]) + weights[i]))
                 tc_intP[i] = tc_int[i] * rho * g * 1e3
-                if(extract_melt is False and tc_intP[i] + P_base_existingLith > P[i]
-                   and tc_found is False):
+                if (extract_melt is False and tc_intP[i] + P_base_existingLith > P[i]
+                        and tc_found is False):
                     tc_found = tc_int[i]
                     P_basecrust = P[i]
                     tc_lith_found = tc_lith_int[i]
@@ -402,6 +404,8 @@ class spreadingCentre(geoSetting):
                 first_lithology = False
 
         weights = self._weighting_coefficients(self.MeltingColumn.P)
+        if isinstance(weights, _np.ndarray) is False:
+            weights = weights.to_numpy()
 
         cm = _np.zeros([len(species)])
         for lith in self.mantle.names:
@@ -422,18 +426,18 @@ class spreadingCentre(geoSetting):
                         for i in range(_np.shape(c)[0] - 1):
                             if f[i] > 0 and f[i - 1] > 0:
                                 cnormed[i + 1] = (_np.sum(0.5 * (c[1:i + 1, j] + c[0:i, j])
-                                                     * df[:i], axis=0) / f[i])
+                                                  * df[:i], axis=0) / f[i])
                             elif f[i] > 0:
                                 cnormed[i + 1] = (_np.sum(c[1:i + 1, j]
-                                                     * df[:i], axis=0) / f[i])
+                                                  * df[:i], axis=0) / f[i])
                             else:
                                 cnormed[i + 1] = 0
                         c[:, j] = cnormed
                 # Normalise melts for this lithology
-                c = trapz((1 + weights[:, None]) * c * f[:, None] / (1.0 - f[:, None]),
-                          self.lithologies[lith]['P'].to_numpy()[:], axis=0)
-                c = c / trapz((1 + weights) * f / (1 - f),
-                              self.lithologies[lith]['P'].to_numpy())
+                c = _trapz((1 + weights[:, None]) * c * f[:, None] / (1.0 - f[:, None]),
+                           self.lithologies[lith]['P'].to_numpy()[:], axis=0)
+                c = c / _trapz((1 + weights) * f / (1 - f),
+                               self.lithologies[lith]['P'].to_numpy())
 
                 # Normalise melts for all lithologies
                 cm += c * self.lithology_contributions[lith]
@@ -527,7 +531,7 @@ class intraPlate(geoSetting):
         The pressure at the base of the lithosphere.
     melt_flux : float or None
         If the melt flux has been calculated, it will be stored here, in m3 s-1.
-    lithology_contributions : pandas.Series
+    lithology_contributions : dict
         The relative contributions of each lithology to the pooled melt.
     chemistry : pandas.Series
         The homogenised melt composition
@@ -536,12 +540,12 @@ class intraPlate(geoSetting):
     def __init__(self, MeltingColumn, P_lithosphere, relative_density=None, viscosity=1e19,
                  radius=1e5, weightingFunction=None, **kwargs):
         self.MeltingColumn = MeltingColumn
-        self.lithologies = copy(MeltingColumn.lithologies)
+        self.lithologies = _copy(MeltingColumn.lithologies)
         self.P_lithosphere = P_lithosphere
         self.mantle = MeltingColumn.mantle
-        self.P = copy(self.MeltingColumn.P)
-        self.T = copy(self.MeltingColumn.T)
-        self.F = copy(self.MeltingColumn.F)
+        self.P = _copy(self.MeltingColumn.P)
+        self.T = _copy(self.MeltingColumn.T)
+        self.F = _copy(self.MeltingColumn.F)
         self.weightingFunction = weightingFunction
         self.kwargs = kwargs
 
@@ -553,9 +557,11 @@ class intraPlate(geoSetting):
         self.P = self.P[self.P > self.P_lithosphere]
 
         # Extract the lithology contributions:
-        self.lithology_contributions = _pd.Series({})
+        self.lithology_contributions = {}
         for lith in self.mantle.names:
+            id = self.mantle.names.index(lith)
             self.lithology_contributions[lith] = (_np.nanmax(self.lithologies[lith].F)
+                                                  * self.mantle.proportions[id]
                                                   / _np.nanmax(self.F))
 
         # Calculate the melt flux.
@@ -603,10 +609,27 @@ class intraPlate(geoSetting):
 
         Where :math:`F` is the total melt fraction obtained.
         """
-        if self.weightingFunction is not None:
-            warn("The weighting function will not be applied to the melt flux.")
         Qv = _np.pi / 8 * (relative_density * 9.81 * radius**4) / viscosity
-        Qm = Qv * self.F.max()
+
+        if self.weightingFunction is None:
+            Qm = Qv * self.F.max()
+        else:
+            w = self._weighting_coefficients(self.P, empty_value=1.0).to_numpy()
+
+            # Create array to store weighted melt fractions for each lithology:
+            weightedF = _np.zeros(len(self.mantle.names))
+
+            for i, lith in zip(range(len(self.mantle.names)), self.mantle.names):
+                f = self.lithologies[lith].F.to_numpy()
+                df = f[1:] - f[:-1]
+                f_normed = (_np.sum(0.5 * df * (w[1:] + w[:-1]), axis=0))
+                weightedF[i] = f_normed
+
+            # Now weight the melt fractions by the abundance of each lithology:
+            totalF = _np.sum(weightedF * self.mantle.proportions)
+
+            Qm = Qv * totalF
+
         return Qm
 
     def _homogenise_chemistry(self):
@@ -628,6 +651,8 @@ class intraPlate(geoSetting):
 
         # Calculate the weighting for each melt
         w = self._weighting_coefficients(self.MeltingColumn.P, empty_value=1.0)
+        if isinstance(w, _np.ndarray) is False:
+            w = w.to_numpy()
 
         for lith in self.mantle.names:
             if self.lithology_contributions[lith] > 0:
@@ -639,7 +664,9 @@ class intraPlate(geoSetting):
                 c = _np.nan_to_num(c, nan=0.0)
                 # Get the melt fractions for the lithology
                 f = self.lithologies[lith].F.to_numpy()
+
                 # If instantaneous melts, need to pool over columns first
+                # If accumulated melts, the existing number at top of column will be used
                 for j in range(len(species)):
                     if self.MeltingColumn._species_calc_type[lith][j] == 'instantaneous':
                         cnormed = _np.zeros(_np.shape(c)[0])
@@ -647,24 +674,27 @@ class intraPlate(geoSetting):
                         for i in range(_np.shape(c)[0] - 1):
                             if f[i] > 0 and f[i - 1] > 0:
                                 cnormed[i + 1] = (_np.sum(0.5 * (c[1:i + 1, j] + c[0:i, j])
-                                                     * df[:i] * w[1:i + 1], axis=0)
-                                                  / _np.sum(df[:i]*w[1:i + 1]))
+                                                  * df[:i] * w[1:i + 1], axis=0)
+                                                  / _np.sum(df[:i] * w[1:i + 1]))
                             elif f[i] > 0:
                                 cnormed[i + 1] = (_np.sum(c[1:i + 1, j]
-                                                     * df[:i] * w[1:i + 1], axis=0)
+                                                  * df[:i] * w[1:i + 1], axis=0)
                                                   / _np.sum(df[:i] * w[1:i + 1]))
                             else:
                                 cnormed[i + 1] = 0
                         c[:, j] = cnormed
+
+                    # If accumulated melts are calculated but a weighting function exists
                     elif self.weightingFunction is not None:
-                        warn("Accumulated melts cannot be used with a weighting function for "
-                             " an intra-plate melting region.")
-                        c[:, j] = [_np.nan]*np.shape(c)[0]
+                        _warn("Accumulated melts cannot be used with a weighting function for "
+                              " an intra-plate melting region.")
+                        c[:, j] = [_np.nan] * _np.shape(c)[0]
+
                 # Normalise melts for all lithologies
                 cm += c[-1, :] * self.lithology_contributions[lith]
             self.chemistry = _pd.Series(cm, species)
 
-    def MeltCrystallisationT(self, ShallowMeltP=None, MeltStorageP=None, liqdTdP=39.16):
+    def meltCrystallisationT(self, ShallowMeltP=None, MeltStorageP=None, liqdTdP=39.16):
         """
         Identifies the crystallisation temperature of the deepest and shallowest melts,
         according to the technique used by Matthews et al. (2016).
