@@ -8,7 +8,6 @@ Implementation of the new lithologies in Shorttle et al. (2014).
 """
 
 from pyMelt.lithology_classes import lithology as _lithology
-from pyMelt.lithology_classes import default_properties as _default_properties
 
 import numpy as _np
 
@@ -18,7 +17,7 @@ class kg1(_lithology):
     Implementation of the KG1 parameterisation by Shorttle et al. (2014).
 
     To use the same format of parameterisation for another lithology, the parameter values
-    may be changed. They are provided as a dictionary during initialisation of the class, with
+    may be changed. They are provided as a dictionary during initialisation of the object, with
     values:
 
     - A1:     Constant used in solidus expression.
@@ -38,47 +37,48 @@ class kg1(_lithology):
     - beta:   Exponent used in the cpx-absent melt fraction expression.
 
     The thermal expansivities, the heat capacity, the densities, and the entropy of fusion may
-    also be changed during class initialisation.
+    also be changed during object initialisation.
 
     Parameters
     ----------
-    CP :         float, default: pyMelt.lithology_class.default_properties['CP']
+    CP :         float, default: 1140.0
         The heat capacity (J K-1 kg-1)
-    alphas :     float, default: pyMelt.lithology_class.default_properties['alphas']
+    alphas :     float, default: 30.0
         The thermal expansivity of the solid (1e-6 K-1)
-    alphaf :     float, default: pyMelt.lithology_class.default_properties['alphaf']
+    alphaf :     float, default: 68.0
         The thermal expansivity of the melt (1e-6 K-1)
-    rhos :       float, default: pyMelt.lithology_class.default_properties['rhos']
+    rhos :       float, default: 3.3
         The density of the solid (kg m-3)
-    rhof :       float, default: pyMelt.lithology_class.default_properties['rhof']
+    rhof :       float, default: 2.9
         The density of the melt (kg m-3)
-    DeltaS :     float, default: pyMelt.lithology_class.default_properties['DeltaS']
+    DeltaS :     float, default: 380.0
         The entropy of fusion J K-1 kg-1
     parameters : dict, default: parameters from Shorttle et al. (2014)
         The model parameters described above
     """
+
     def __init__(self,
-                 CP=_default_properties['CP'],
-                 alphas=_default_properties['alphas'],
-                 alphaf=_default_properties['alphaf'],
-                 rhos=_default_properties['rhos'],
-                 rhof=_default_properties['rhof'],
-                 DeltaS=_default_properties['DeltaS'],
-                 parameters={'A1':    1095.4,
-                             'A2':     124.1,
+                 CP=1140.0,
+                 alphas=30.0,
+                 alphaf=68.0,
+                 rhos=3.3,
+                 rhof=2.9,
+                 DeltaS=380.0,
+                 parameters={'A1': 1095.4,
+                             'A2': 124.1,
                              'A3': - 4.7,
-                             'B1':    1179.6,
-                             'B2':     157.2,
+                             'B1': 1179.6,
+                             'B2': 157.2,
                              'B3': - 11.1,
-                             'C1':    1780.0,
-                             'C2':      45.0,
+                             'C1': 1780.0,
+                             'C2': 45.0,
                              'C3': - 2.0,
-                             'a':        0.3187864,
-                             'b':        0.4154,
-                             'c':        0.7341864,
-                             'd':        0.2658136,
-                             'alpha':    2.0,
-                             'beta':     1.5
+                             'a': 0.3187864,
+                             'b': 0.4154,
+                             'c': 0.7341864,
+                             'd': 0.2658136,
+                             'alpha': 2.0,
+                             'beta': 1.5
                              }
                  ):
 
@@ -104,7 +104,7 @@ class kg1(_lithology):
         float, or list like
             Solidus Temperature in degC.
         """
-        T = self.parameters['A1'] + self.parameters['A2']*P + self.parameters['A3']*P**2
+        T = self.parameters['A1'] + self.parameters['A2'] * P + self.parameters['A3'] * P**2
         return T
 
     def TLiquidus(self, P, **kwargs):
@@ -121,7 +121,7 @@ class kg1(_lithology):
         float, or list like
             Liquidus temperature in degC.
         """
-        T = self.parameters['C1'] + self.parameters['C2']*P + self.parameters['C3']*P**2
+        T = self.parameters['C1'] + self.parameters['C2'] * P + self.parameters['C3'] * P**2
         return T
 
     def dTdP(self, P, T, **kwargs):
@@ -144,16 +144,20 @@ class kg1(_lithology):
         Tliq = self.TLiquidus(P, **kwargs)
         Tcpx = self._TCpxOut(P, **kwargs)
 
+        if T < Tsol:
+            dTdP = self.alphas / self.rhos / self.CP
         if T < Tcpx:
-            dTdP = (-(-(T - Tsol) / (Tcpx - Tsol) *
-                    (self.parameters['B2'] + 2*self.parameters['B3']*P -
-                     self.parameters['A2'] - self.parameters['A3']*2*P) -
-                    self.parameters['A2'] - self.parameters['A3']*2*P))
+            dTdP = (-(-(T - Tsol) / (Tcpx - Tsol)
+                    * (self.parameters['B2'] + 2 * self.parameters['B3'] * P
+                       - self.parameters['A2'] - self.parameters['A3'] * 2 * P)
+                    - self.parameters['A2'] - self.parameters['A3'] * 2 * P))
+        elif T < Tliq:
+            dTdP = (-(-(T - Tcpx) / (Tliq - Tcpx)
+                    * (self.parameters['C2'] + self.parameters['C3'] * 2 * P
+                       - self.parameters['B2'] - self.parameters['B3'] * 2 * P)
+                    - self.parameters['B2'] - 2 * self.parameters['B3'] * P))
         else:
-            dTdP = (-(-(T - Tcpx) / (Tliq - Tcpx) *
-                    (self.parameters['C2'] + self.parameters['C3']*2*P -
-                     self.parameters['B2'] - self.parameters['B3']*2*P) -
-                    self.parameters['B2'] - 2*self.parameters['B3']*P))
+            dTdP = self.alphas / self.rhos / self.CP
 
         return dTdP
 
@@ -181,13 +185,13 @@ class kg1(_lithology):
         if T < Tsol:
             dTdF = _np.inf
         elif T < Tcpx:
-            dTdF = ((Tcpx-Tsol) /
-                    (self.parameters['b'] + self.parameters['a'] *
-                     self.parameters['alpha'] *
-                     ((T-Tsol)/(Tcpx-Tsol))**(self.parameters['alpha']-1)))
+            dTdF = ((Tcpx - Tsol)
+                    / (self.parameters['b'] + self.parameters['a']
+                       * self.parameters['alpha']
+                       * ((T - Tsol) / (Tcpx - Tsol))**(self.parameters['alpha'] - 1)))
         elif T < Tliq:
-            dTdF = ((Tliq - Tcpx)/(self.parameters['d'] * self.parameters['beta'] *
-                    ((T-Tcpx)/(Tliq-Tcpx))**(self.parameters['beta']-1)))
+            dTdF = ((Tliq - Tcpx) / (self.parameters['d'] * self.parameters['beta']
+                    * ((T - Tcpx) / (Tliq - Tcpx))**(self.parameters['beta'] - 1)))
         else:
             dTdF = _np.inf
 
@@ -227,10 +231,10 @@ class kg1(_lithology):
         elif T > Tliq:
             F = 1.0
         elif T < Tcpx:
-            Tf = (T-Tsol)/(Tcpx-Tsol)
-            F = self.parameters['a'] * Tf**self.parameters['alpha'] + self.parameters['b']*Tf
+            Tf = (T - Tsol) / (Tcpx - Tsol)
+            F = self.parameters['a'] * Tf**self.parameters['alpha'] + self.parameters['b'] * Tf
         else:
-            Tf = (T-Tcpx)/(Tliq-Tcpx)
+            Tf = (T - Tcpx) / (Tliq - Tcpx)
             F = self.parameters['d'] * Tf**self.parameters['beta'] + self.parameters['c']
         return F
 
@@ -248,43 +252,43 @@ class kg1(_lithology):
         float, or list like
             Cpx-exhaustion temperature in degC.
         """
-        T = self.parameters['B1'] + self.parameters['B2']*P + self.parameters['B3']*P**2
+        T = self.parameters['B1'] + self.parameters['B2'] * P + self.parameters['B3'] * P**2
         return T
 
 
 class harzburgite(_lithology):
     """
     Material that does not melt, i.e. Harzburgite in Shorttle et al. (2014) and
-    Matthews et al. (2016). Default thermodynamic constants are those used by
-    Katz et al. (2003).
+    Matthews et al. (2016). Default constants as defined by Shorttle et al. (2014).
 
     The thermal expansivities, the heat capacity, the densities, and the entropy of fusion may
-    be changed during class initialisation.
+    be changed during object initialisation.
 
     Parameters
     ----------
-    CP :         float, default: pyMelt._default_properties['CP']
+    CP :         float, default: 1000.0
         The heat capacity (J K-1 kg-1)
-    alphas :     float, default: pyMelt._default_properties['alphas']
+    alphas :     float, default: 30.0
         The thermal expansivity of the solid (1e-6 K-1)
-    alphaf :     float, default: pyMelt._default_properties['alphaf']
+    alphaf :     float, default: 30.0
         Melt thermal expansivity, not used, here for consistency.
-    rhos :       float, default: pyMelt._default_properties['rhos']
+    rhos :       float, default: 3.25
         The density of the solid (kg m-3)
-    rhof :       float, default: pyMelt._default_properties['rhof']
+    rhof :       float, default: 2.9
         Melt density, not used, here for consistency.
-    DeltaS :     float, default: pyMelt._default_properties['DeltaS']
+    DeltaS :     float, default: 300
         The entropy of fusion, not used, here for consistency.
     parameters : dict, default: {}
         This model does not use any parameters, here for consistency.
     """
+
     def __init__(self,
-                 CP=_default_properties['CP'],
-                 alphas=_default_properties['alphas'],
-                 alphaf=_default_properties['alphaf'],
-                 rhos=_default_properties['rhos'],
-                 rhof=_default_properties['rhof'],
-                 DeltaS=_default_properties['DeltaS'],
+                 CP=1000.0,
+                 alphas=30.0,
+                 alphaf=30.0,
+                 rhos=3.25,
+                 rhof=2.9,
+                 DeltaS=300,
                  parameters={}
                  ):
         self.CP = CP
@@ -347,7 +351,8 @@ class harzburgite(_lithology):
         float
             The value will always be 0.0.
         """
-        return 0.0
+        dTdP = self.alphas / self.rhos / self.CP
+        return dTdP
 
     def TSolidus(self, P, **kwargs):
         """
@@ -364,7 +369,7 @@ class harzburgite(_lithology):
             The value will always be infinite.
         """
         if isinstance(P, list) or isinstance(P, _np.ndarray):
-            return _np.array([_np.inf]*len(P))
+            return _np.array([_np.inf] * len(P))
         else:
             return _np.inf
 
@@ -383,6 +388,6 @@ class harzburgite(_lithology):
             The value will always be infinite.
         """
         if isinstance(P, list) or isinstance(P, _np.ndarray):
-            return _np.array([_np.inf]*len(P))
+            return _np.array([_np.inf] * len(P))
         else:
             return _np.inf
