@@ -6,18 +6,19 @@ Lithology classes
 The lithology classes module provides the `lithology` class for implementing melting models, and
 the `hydrous_lithology` class for converting an anhydrous lithology to a hydrous lithology.
 """
-from scipy.misc import derivative
-from scipy.optimize import root_scalar
+from scipy.misc import derivative as _derivative
+from scipy.optimize import root_scalar as _root_scalar
 import numpy as _np
 from pyMelt.core import ConvergenceError
+from warnings import warn as _warn
 
 # Default constant values taken from Katz et al., 2003:
-default_properties = {'CP':     1000.0,  # Heat capacity in J Kg-1 K-1
-                      'alphas':   40.0,  # Thermal expansivity of the solid (K-1).
-                      'alphaf':   68.0,  # Thermal expansivity of the melt (K-1).
-                      'rhos':      3.3,  # Density of the solid (g cm-3).
-                      'rhof':      2.9,  # Density of the melt (g cm-3).
-                      'DeltaS':  300.0,  # Entropy of fusion. (J kg-1 K-1).
+default_properties = {'CP': 1000.0,  # Heat capacity in J Kg-1 K-1
+                      'alphas': 40.0,  # Thermal expansivity of the solid (K-1).
+                      'alphaf': 68.0,  # Thermal expansivity of the melt (K-1).
+                      'rhos': 3.3,  # Density of the solid (g cm-3).
+                      'rhof': 2.9,  # Density of the melt (g cm-3).
+                      'DeltaS': 300.0,  # Entropy of fusion. (J kg-1 K-1).
                       }
 
 
@@ -26,10 +27,8 @@ class lithology(object):
     Lithology base class. This class contains all the parameters and methods required to calculate
     the melting behaviour of a single mantle component.
 
-    Attributes
+    Parameters
     ----------
-    DeltaS:     float
-        Entropy of fusion. (J kg-1 K-1). Default is 300.0.
     CP:     float
         Heat capacity (J Kg-1 K-1). Default is 1000.0.
     alphas:     float
@@ -40,6 +39,10 @@ class lithology(object):
         Density of the solid (g cm-3). Default is 3.3.
     rhof:   float
         Density of the melt (g cm-3). Default is 2.9.
+    DeltaS:     float
+        Entropy of fusion. (J kg-1 K-1). Default is 300.0.
+    parameters: dict
+        A dictionary of the parameters required by the lithology.
 
     """
 
@@ -132,7 +135,7 @@ class lithology(object):
         def _to_diff(T, P, kwargs={}):
             return self.F(P, T, **kwargs)
 
-        return 1.0/(derivative(_to_diff, T, dx=0.1, args=(P, kwargs)))
+        return 1.0 / (_derivative(_to_diff, T, dx=0.001, args=(P, kwargs)))
 
     def dTdP(self, P, T, **kwargs):
         """
@@ -151,19 +154,35 @@ class lithology(object):
         float
             dT/dP(const. F) (K GPa-1).
         """
-        dTdF = self.dTdF(P, T, **kwargs)
 
-        def _to_diff(P, T, kwargs={}):
-            return self.F(P, T, **kwargs)
+        # This finds the temperature at a given pressure for which the melt fraction is eqal to the
+        # value specified. Used for calculating dT/dP (at const. F).
+        def _to_diff_dTdP(P, F, T, kwargs={}):
+            t = _root_scalar(_hold_constant_F, x0=T, x1=T + 10, args=(P, F, kwargs)).root
+            return t
 
-        dFdP = derivative(_to_diff, P, args=(T, kwargs))
+        # This method is used to find the P-T curve at which F remains constant, for the
+        # calculation of dT/dP (at const. F).
+        def _hold_constant_F(t, P, F, kwargs={}):
+            return self.F(P, t, **kwargs) - F
 
-        return dTdF*dFdP
+        if self.F(P, T, **kwargs) == 0:
+            dTdP = self.alphas / self.rhos / self.CP
+
+        elif self.F(P, T, **kwargs) == 1:
+            dTdP = self.alphas / self.rhos / self.CP
+
+        else:
+            F = self.F(P, T, **kwargs)
+
+            dTdP = _derivative(_to_diff_dTdP, P, dx=0.001, args=(F, T, kwargs))
+
+        return dTdP
 
 
-class hydrous_lithology(object):
-    """
-    The hydrous lithology class modifies the melting expressions in a given lithology class so
+class hydrousLithology(object):
+    r"""
+    The hydrous lithology class modifies the melting expressions in a given lithology object so
     that water-present melting can be modelled.
 
     Parameters
@@ -260,9 +279,9 @@ class hydrous_lithology(object):
 
     def melt_H2O(self, F, P=None):
         """
-        Returns the H2O content of the melt at a particular melt fraction, assuming batch
-        melting, and H2O saturation controlled by the H2O_saturation method. If H2O is
-        saturated, it will remain in the bulk system.
+        Returns the H2O content of the melt at a particular melt fraction, assuming either batch
+        or continuous melting, and H2O saturation controlled by the H2O_saturation method. If H2O
+        is saturated, it will remain in the bulk system.
 
         Parameters
         ----------
@@ -279,15 +298,18 @@ class hydrous_lithology(object):
         """
 
         if self.continuous is False:
-            Cl = self.H2O/((1.0 - F)*self.D + F)
+            Cl = self.H2O / ((1.0 - F) * self.D + F)
         else:
-            Cl = (self.H2O / ((1-self.phi)*self.D + self.phi)
-                  * (1-F)**((1-self.phi)*(1-self.D)/((1-self.phi)*self.D)))
+            Cl = (self.H2O / ((1 - self.phi) * self.D + self.phi)
+                  * (1 - F)**((1 - self.phi) * (1 - self.D) / ((1 - self.phi) * self.D)))
 
         # Test for H2O saturation:
         if P is not None:
             H2Osat = self.H2O_saturation(P)
             if H2Osat < Cl:
+                if self.continuous:
+                    _warn("Fluid saturated during continuous melting- you may get bizarre "
+                          "behaviour")
                 Cl = H2Osat
 
         return Cl
@@ -307,7 +329,7 @@ class hydrous_lithology(object):
 
         Returns
         -------
-        Tsol:   float
+        float
             Solidus temperature (degC).
         """
 
@@ -318,13 +340,14 @@ class hydrous_lithology(object):
     def TLiquidus(self, P, **kwargs):
         """
         Returns the temperature of the liquidus at any given pressure.
+
         Parameters
         ----------
         P:  float
             Pressure (GPa).
         Returns
         -------
-        Tliq:   float
+        float
             Liquidus temperature (degC).
         """
         return self.lithology.TLiquidus(P)
@@ -358,10 +381,10 @@ class hydrous_lithology(object):
             if anhydrous_F > self.threshold_F:
                 return anhydrous_F
 
-        F = root_scalar(self._f_to_solve, bracket=[0, 1], args=(P, T))
+        F = _root_scalar(self._f_to_solve, bracket=[0, 1], args=(P, T))
 
         if F.flag != 'converged':
-            raise convergenceError('The melt fraction calculation did not converge.')
+            raise ConvergenceError('The melt fraction calculation did not converge.')
             return _np.nan
         else:
             return F.root
@@ -382,8 +405,9 @@ class hydrous_lithology(object):
         float
             dT/dF(const. P) (K).
         """
-
-        return 1.0/(derivative(self._to_diff_dTdF, T, dx=0.001, args=(P, kwargs)))
+        if self.F(P, T, **kwargs) == 0 or self.F(P, T, **kwargs) == 1:
+            return _np.inf
+        return 1.0 / (_derivative(self._to_diff_dTdF, T, dx=0.001, args=(P, kwargs)))
 
     def dTdP(self, P, T, **kwargs):
         """
@@ -406,13 +430,13 @@ class hydrous_lithology(object):
             dT/dP(const. F) (K GPa-1).
         """
         if self.F(P, T, **kwargs) == 0:
-            dTdP = self.alphas/self.rhos/self.CP
+            dTdP = self.alphas / self.rhos / self.CP
         elif self.F(P, T, **kwargs) == 1:
-            dTdP = self.alphas/self.rhos/self.CP
+            dTdP = self.alphas / self.rhos / self.CP
         else:
             F = self.F(P, T, **kwargs)
 
-            dTdP = derivative(self._to_diff_dTdP, P, dx=0.001, args=(F, T, kwargs))
+            dTdP = _derivative(self._to_diff_dTdP, P, dx=0.001, args=(F, T, kwargs))
 
         return dTdP
 
@@ -432,12 +456,11 @@ class hydrous_lithology(object):
     # This finds the temperature at a given pressure for which the melt fraction is eqal to the
     # value specified. Used for calculating dT/dP (at const. F).
     def _to_diff_dTdP(self, P, F, T, kwargs={}):
-        t = root_scalar(self._hold_constant_F, x0=T, x1=T+10, args=(P, F, kwargs)).root
+        t = _root_scalar(self._hold_constant_F, x0=T, x1=T + 10, args=(P, F, kwargs)).root
         return t
 
     # This provides the misfit function when solving for F (Eqn. 19 of Katz et al., 2003)
     def _f_to_solve(self, x, P, T):
-        misfit = 0
         fcalc = self.F_function(P, T, F=x)
         misfit = fcalc - x
         return misfit
